@@ -1,33 +1,20 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 
-#ifndef LIBKGAPI2_TASKLIST_H
-#define LIBKGAPI2_TASKLIST_H
+#pragma once
 
 #include "object.h"
 #include "types.h"
 #include "kgapitasks_export.h"
 
+#include <QScopedPointer>
+
 namespace KGAPI2
 {
 
@@ -82,13 +69,36 @@ class KGAPITASKS_EXPORT TaskList: public KGAPI2::Object
      */
     QString title() const;
 
+    /**
+     * @brief Sets tasklist selfLink
+     *
+     * @param selfLink
+     */
+    void setSelfLink(const QString &selfLink);
+
+    /**
+     * @brief Returns tasklist selfLink
+     */
+    QString selfLink() const;
+
+    /**
+     * @brief Sets tasklist updated
+     *
+     * @param updated
+     */
+    void setUpdated(const QString &updated);
+
+    /**
+     * @brief Returns tasklist updated
+     */
+    QString updated() const;
+
   private:
     class Private;
-    Private * const d;
+    QScopedPointer<Private> const d;
     friend class Private;
 
 };
 
 } // namespace KGAPI2
 
-#endif // LIBKGAPI2_TASKLIST_H
